@@ -1,6 +1,7 @@
 package util
 
 import (
+	"context"
 	"fmt"
 
 	"github.com/onsi/ginkgo"
@@ -14,7 +15,7 @@ import (
 	"k8s.io/client-go/tools/clientcmd"
 	clientcmdapi "k8s.io/client-go/tools/clientcmd/api"
 
-	workapiv1 "github.com/open-cluster-management/api/work/v1"
+	workapiv1 "open-cluster-management.io/api/work/v1"
 )
 
 func HaveManifestCondition(conditions []workapiv1.ManifestCondition, expectedType string, expectedStatuses []metav1.ConditionStatus) bool {
@@ -141,5 +142,9 @@ func (r *IntegrationTestEventRecorder) Warningf(reason, messageFmt string, args
 	r.Warning(reason, fmt.Sprintf(messageFmt, args...))
 }
 
+func (r *IntegrationTestEventRecorder) WithContext(ctx context.Context) events.Recorder {
+	return r
+}
+
 func (r *IntegrationTestEventRecorder) Shutdown() {
 }
